@@ -394,6 +394,85 @@ pub fn get_args(version: &str) -> ArgMatches {
                         .value_name("STRING"),
                 ),
         )
+        .subcommand(
+            App::new("summary")
+                .about("Gets alignment summary stats")
+                .arg(
+                    Arg::with_name("input")
+                        .short("i")
+                        .long("input")
+                        .help("Gets summary from a file")
+                        .takes_value(true)
+                        .required_unless("dir")
+                        .conflicts_with_all(&["dir", "wildcard"])
+                        .value_name("PATH"),
+                )
+                .arg(
+                    Arg::with_name("dir")
+                        .short("d")
+                        .long("dir")
+                        .help("Gets summary from alignment files")
+                        .takes_value(true)
+                        .conflicts_with_all(&["input", "wildcard"])
+                        .value_name("PATH"),
+                )
+                .arg(
+                    Arg::with_name("wildcard")
+                        .short("c")
+                        .long("wcard")
+                        .help("Uses wildcard as an input")
+                        .takes_value(true)
+                        .multiple(true)
+                        .required_unless("input")
+                        .conflicts_with_all(&["input", "dir"])
+                        .value_name("WILDCARD"),
+                )
+                .arg(
+                    Arg::with_name("input-format")
+                        .short("f")
+                        .long("input-format")
+                        .help("Sets input format")
+                        .takes_value(true)
+                        .required(true)
+                        .value_name("SEQ-FORMAT")
+                        .default_value("auto")
+                        .possible_values(&[
+                            "auto",
+                            "fasta",
+                            "nexus",
+                            "phylip",
+                        ]),
+                )
+                .arg(
+                    Arg::with_name("output")
+                        .short("o")
+                        .long("output")
+                        .help("Uses a costume output filename")
+                        .takes_value(true)
+                        .required(true)
+                        .default_value("SEGUL-stats")
+                        .value_name("STRING"),
+                )
+                .arg(
+                    Arg::with_name("datatype")
+                        .long("datatype")
+                        .help("Sets data type")
+                        .takes_value(true)
+                        .required(true)
+                        .value_name("DATATYPE")
+                        .default_value("dna")
+                        .possible_values(&["dna", "aa", "ignore"]),
+                )
+                .arg(
+                    Arg::with_name("percent-interval")
+                        .long("interval")
+                        .help("Sets a custom percentage interval value for counting data matrix completeness")
+                        .takes_value(true)
+                        .value_name("INTEGER")
+                        .default_value("5")
+                        .possible_values(&["1", "2", "5", "10"]),
+                ),
+        )
         .subcommand(
             App::new("extract")
                 .about("Extract sequences from a collection of alignments")
@@ -445,7 +524,7 @@ pub fn get_args(version: &str) -> ArgMatches {
                 .arg(
                     Arg::with_name("file")
                         .long("file")
-                        .help("Extract sequence IDs that match regular expression")
+                        .help("Inputs sequence IDs in a file")
                         .conflicts_with_all(&["id", "regex"])
                         .takes_value(true)
                         .value_name("A-TEXT-FILE-PATH")       
@@ -453,7 +532,7 @@ pub fn get_args(version: &str) -> ArgMatches {
                 .arg(
                     Arg::with_name("id")
                         .long("id")
-                        .help("Extract sequence in a list of IDs")
+                        .help("Extract sequence using a list of IDs")
                         .conflicts_with_all(&["regex", "file"])
                         .required_unless_all(&["regex", "file"])
                         .takes_value(true)
